@@ -1,4 +1,4 @@
-/* $Id: RTErrConvertFromErrno.cpp 102121 2015-08-14 15:16:38Z bird $ */
+/* $Id: RTErrConvertFromErrno.cpp 103594 2015-10-22 11:46:40Z bird $ */
 /** @file
  * IPRT - Convert errno to iprt status codes.
  */
@@ -119,7 +119,7 @@ RTDECL(int)  RTErrConvertFromErrno(unsigned uNativeCode)
         case EINVAL:            return VERR_INVALID_PARAMETER;
 #endif
 #ifdef ENFILE
-        case ENFILE:            return VERR_TOO_MANY_OPEN_FILES; /**@Todo fix duplicate error */
+        case ENFILE:            return VERR_TOO_MANY_OPEN_FILES; /** @todo fix duplicate error */
 #endif
 #ifdef EMFILE
         case EMFILE:            return VERR_TOO_MANY_OPEN_FILES;
